@@ -75,15 +75,15 @@ public abstract class Json extends #1.SuperPage implements Downloadable {
 
 	private class LastJson implements Serializable {
 		private static final long serialVersionUID = 2L;
-		RequestParameter	req;
+		Integer	req;
 		JSON	json;
 		LastJson(){}
 		LastJson( RequestParameter r, JSON j ) {
-			req = r;
+			req = r.hashCode();
 			json = j;
 		}
 		JSON getLastJson( RequestParameter r ) {
-			if ( req.equals( r ) )	return json;
+			if ( r.equals( req ) )	return json;
 			return null;
 		}
 	}
