@@ -453,6 +453,19 @@ public abstract class Page implements Serializable {
 		return null;
 	}
 
+	private Page	agency_page = null;
+	/**
+	 * フレームワークが使用します。
+	 */
+	public void setAgencyPage( Page page ) {
+		if ( page == this ) {
+			agency_page = null;
+		}
+		else {
+			agency_page = page;
+		}
+	}
+
 	/**
 	 * リクエスト内容をフォームに反映する。
 	 * input()メソッドを呼ぶ直前にはreflect()がコールされています。
@@ -468,6 +481,11 @@ public abstract class Page implements Serializable {
 			c.setClicked( false );
 		}
 
+		if ( agency_page != null ) {
+			Page	page = agency_page.reflect( req );
+			if ( page != null )	return page;
+		}
+
 		PageBypassedDiv[]	div = getPageBypassedDiv();
 		for ( int i = 0; i < div.length; i++ ) {
 			Page	page = div[i].getBypassPage();
@@ -1005,9 +1023,11 @@ public abstract class Page implements Serializable {
 
 	/**
 	 * ロード時に実行する JavaScript の登録。
-	 * このページがブラウザにロードされた時に実行したいスクリプトの指定。<br>
+	 * このページがブラウザにロードされた時に実行したいスクリプトの指定。
+	 * <br>
 	 * このメソッドの呼び出しの度にスクリプトが追加されます。
-	 * また、このページがブラウザへ出力されると、この登録内容がクリアされます。
+	 * また、このページがブラウザへ出力されると、この登録内容がクリア
+	 * されます。
 	 * @param script 実行スクリプト。各Stringには改行が付けられます。
 	 */
 	public void addOnLoadScript( String ... script ) {
@@ -1038,7 +1058,7 @@ public abstract class Page implements Serializable {
 		getOnloadTag().removeHTMLPart();
 		getOnloadTag().addHTMLPart( new paraselene.ajax.data.JavaScript() );
 		if ( getAjaxSupport() == Page.AjaxSupport.SERVER_PUSH ) {
-			StringBuilder	buf = new StringBuilder( "paraselene_comet_start('" );
+			StringBuilder	buf = new StringBuilder( "paraselene.comet_start('" );
 			buf = buf.append( getUniqueKey() );
 			buf = buf.append( "');" );
 			addOnLoadScript( buf.toString() );
@@ -1164,12 +1184,17 @@ public abstract class Page implements Serializable {
 		if ( beginning_called )	return;
 		beginning_called = true;
 		if ( getMainTag() == null )	return;
+		body_tag = getFirstTagByType( "body" );
 		firstOutput( req );
+		if ( this instanceof FramesetPage || this instanceof Downloadable ) {
+			ajax_f = false;
+			return;
+		}
 		ajax_f = true;
 		if ( getAccessedMobile() == RequestParameter.Mobile.NO_MOBILE && getAccessedSearchEngine() == RequestParameter.SearchEngine.NO_SEARCHENGINE ) {
 			AjaxSupport	ajax = getAjaxSupport();
 			Tag	head = getFirstTagByType( "head" );
-			Tag	body = getFirstTagByType( "body" );
+			Tag	body = body_tag;
 			if ( head != null ) {
 				int	idx = 0;
 				int	max = head.getHTMLPartCount();
@@ -1209,13 +1234,14 @@ public abstract class Page implements Serializable {
 				Tag[]	div = new Tag[] { new Tag( "div", false ), new Tag( "div", false ) };
 				root_id = div[0].makeID();
 				div[0].include( body, true );
+				body_tag = div[0];
 				Tag eclipse = new Tag( "div", false );
 				eclipse.setAttribute(
 					new Attribute( "id", AJAX_BLACK_ID )
 				);
 				Tag	iframe = new Tag( "iframe", false );
 				iframe.setAttribute(
-					new Attribute( "onload", "paraselene_form_comp();" ),
+					new Attribute( "onload", "paraselene.form_comp();" ),
 					new Attribute( "id", AJAX_TARGET_ID ),
 					new Attribute( "name", AJAX_TARGET_ID ),
 					new Attribute( "scrolling", new Text( "no" ) )
@@ -1250,6 +1276,49 @@ public abstract class Page implements Serializable {
 	private RequestParameter.Mobile			access_mobile;
 	private RequestParameter.SearchEngine	access_se;
 	private Tag	onload_tag = null;
+	private Tag	body_tag = null;
+
+	/**
+	 * body タグを返します。次のように機能します。
+<table border="1">
+  <tbody>
+    <tr>
+      <th rowspan="2">メソッド</th>
+      <th colspan="2">Ajax</th>
+    </tr>
+    <tr>
+      <th>無効時</th>
+      <th>有効時</th>
+    </tr>
+    <tr>
+      <td>init</td>
+      <td colspan="2">null</td>
+    </tr>
+    <tr>
+      <td>firstOutput</td>
+      <td colspan="2">&lt;body&gt;</td>
+    </tr>
+    <tr>
+      <td>output</td>
+      <td rowspan="2">&lt;body&gt;</td>
+      <td rowspan="2">&lt;div&gt;</td>
+    </tr>
+    <tr>
+      <td>input</td>
+    </tr>
+  </tbody>
+</table>
+	 * Ajax 有効時には、本来の body 内容は、その直下の div に移動します。
+	 * <br>body 直下には Paraselene が Ajax 処理を行うためのタグを
+	 * 追加・削除させてきますので、body タグ内容は操作しないで下さい。<br>
+	 * div へ移動するタイミングは、firstOutput 呼び出し直後です。<br>
+	 * そのため、firstOutput 中でのこのメソッドの戻り値は、常に
+	 * body タグを返します。
+	 * @return body 内容を持っているタグ。
+	 */
+	public Tag getBodyTag() {
+		return body_tag;
+	}
 
 	private Tag getOnloadTag() {
 		if ( onload_tag != null )	return onload_tag;
