@@ -30,7 +30,7 @@ public class History implements Serializable {
 	volatile String	session_id;
 
 	private void comet_stop( Page p ) {
-		StringBuilder	buf = new StringBuilder( "paraselene_comet_stop('" );
+		StringBuilder	buf = new StringBuilder( "paraselene.comet_stop('" );
 		buf = buf.append( p.getUniqueKey() );
 		buf = buf.append( "');" );
 		Ajax.addComet( session_id, new PostBack( new Exec( buf.toString() ) ) );
@@ -154,6 +154,15 @@ public class History implements Serializable {
 			}
 			cnt = getHistoryCount();
 			if ( cnt == 0 || old != getPage() ) {
+				if ( cnt > 0 && old != null ) {
+					Option.trace(
+						String.format( "old=%s(%s) / new=%s(%s)",
+							old.getID().toString(), old.getUniqueKey(),
+							getPage().getID().toString(),
+							getPage().getUniqueKey()
+						)
+					);
+				}
 				clearPopup();
 			}
 		}
