@@ -23,6 +23,7 @@ class Child extends Thread implements DaemonChannel {
 
 	volatile Page main_page = null;
 	volatile boolean call_input;
+	volatile boolean refresh_f;
 	volatile RequestParameter request = null;
 	volatile Forward forward = null;
 	volatile Page param_page = null;
@@ -176,28 +177,41 @@ class Child extends Thread implements DaemonChannel {
 		return page.input( req, fw );
 	}
 
-	private static Page output( Page page, Page from, RequestParameter req ) throws Exception {
+	private static Page output( Page page, Page from, RequestParameter req, boolean new_f ) throws Exception {
 		if ( page == null )	return null;
 		Page	old = page;
 		page.beginning( req );
 		page = page.output( from, req );
 		if ( page == null )	page = old;
+		Tag	body = page.getBodyTag();
+		if ( body != null ) {
+			if ( body.isModified() ) {
+				new_f = true;
+			}
+		}
 
 		PageBypassedDiv[]	div = page.getPageBypassedDiv();
 		for ( int i = 0; i < div.length; i++ ) {
-			div[i].setView( output( div[i].getBypassPage(), from, req ) );
+			boolean	div_new = div[i].isModified();
+			div[i].setView( output( div[i].getBypassPage(), from, req, div_new ) );
 		}
 
 		PageHooker[]	hook = page.getPageHooker();
-		if ( page.isAjax() ) {
+		if ( page.isAjax() && !new_f ) {
 			Tag[]	t = page.getModifiedTag();
 			ArrayList<PageHooker>	list = new ArrayList<PageHooker>();
 			for ( int i = 0; i < t.length; i++ ) {
+
 				PageHooker[]	tmp = t[i].getInnerHTMLPart( hook );
 				for ( int j = 0; j < tmp.length; j++ ) {
 					list.add( tmp[j] );
 				}
 			}
+			for ( int i = 0; i < hook.length; i++ ) {
+				if ( hook[i] instanceof PageBypassedDiv ) {
+					list.add( hook[i] );
+				}
+			}
 			hook = list.toArray( new PageHooker[0] );
 		}
 		for ( int i = 0; i < hook.length; i++ ) {
@@ -226,7 +240,7 @@ class Child extends Thread implements DaemonChannel {
 				forward = input( main_page, request, forward );
 			}
 			else {
-				param_page = output( main_page, param_page, request );
+				param_page = output( main_page, param_page, request, refresh_f );
 
 			}
 		}
@@ -443,7 +457,7 @@ public class SandBox extends Thread {
 		long	last_tm = new Date().getTime();
 
 		while( true ) {
-			if ( waiting == null )	return;
+			if ( waiting == null || running == null )	return;
 			try {
 				synchronized( waiting ) {
 					int cnt = waiting.size();
@@ -477,6 +491,7 @@ public class SandBox extends Thread {
 				}
 				long	time_sub = new Date().getTime() - last_tm;
 				int	cnt = 0;
+				if ( running == null )	break;
 				synchronized( running ) {
 					cnt = running.size() - running_last_cnt;
 				}
@@ -496,7 +511,7 @@ public class SandBox extends Thread {
 			}
 			catch( Exception e ) {
 				try {
-					//e.printStackTrace();
+					e.printStackTrace();
 					Thread.sleep( 1000 );
 				}
 				catch( Exception ee ) {}
@@ -662,13 +677,14 @@ public class SandBox extends Thread {
 		return child.forward;
 	}
 
-	static Page output( Page action, Page page, RequestParameter req )
+	static Page output( Page action, Page page, RequestParameter req, boolean refresh_f )
 	throws Throwable {
 		Child	child = getChild();
 		child.main_page = action;
 		child.param_page = page;
 		child.request = req;
 		child.call_input = false;
+		child.refresh_f = refresh_f;
 		kick( child );
 		return child.param_page;
 	}
