@@ -134,13 +134,15 @@ class SessionData implements Serializable, HttpSessionBindingListener {
 		rd.out_page = out_ret;
 		rd.posted = req.getURI();
 		rd.uri = TransactionSequencer.makeRedirectURI( seq, out_ret[0].getID() );
-		String	path = URIValue.makeAbsolutePath(
-			URIValue.Scheme.getScheme( rd.posted ), rd.posted.getPort(), rd.uri
+		String	path = Supervisor.makeWithSessionURI(
+			URIValue.makeAbsolutePath(
+				URIValue.Scheme.getScheme( rd.posted ), rd.posted.getPort(), rd.uri
+			), null, null
 		);
 		synchronized( pending ) {
 			pending.put( out_ret[0].getID(), rd );
 		}
-		rd.redirect_path = new URI( path );
+		rd.redirect_path = new URI( rd.uri );
 		return new Forward( rd.redirect_path, false );
 	}
 
