@@ -650,8 +650,12 @@ public abstract class Supervisor extends HttpServlet {
 					Ajax.add( session, key, oh.getPostBack() );
 					Page	ajax_page = getPageFactory().getPage( PAGE_ID_FORM_JSON );
 					ajax_page.output( last_page, req );
-					data.redirect( new Page[]{ ajax_page, ajax_page }, fw, req ).Action( this, res );
-					//write( new Page[]{ ajax_page, ajax_page }, session_f, fw, holder );
+					if ( isPRG() ) {
+						data.redirect( new Page[]{ ajax_page, ajax_page }, fw, req ).Action( this, res );
+					}
+					else {
+						write( new Page[]{ ajax_page, ajax_page }, session_f, fw, holder );
+					}
 					Option.trace( "FORM postback %s", key );
 					return;
 				}
@@ -671,6 +675,12 @@ public abstract class Supervisor extends HttpServlet {
 		}
 	}
 
+	/**
+	 * PRGパターン遷移の使用。
+	 * @return true:PRGパターンを使用、false:通常のPOST遷移。
+	 */
+	public abstract boolean isPRG();
+
 	private static final int PAGE_ID_JSON = -1;
 	private static final int PAGE_ID_FORM_JSON = -2;
 	/**
@@ -741,7 +751,7 @@ public abstract class Supervisor extends HttpServlet {
 			session = holder.getRequest().getSession( true );
 			session.setAttribute( SESSION_DATA, data );
 		}
-		if ( !session_f && param.getMethod() == RequestParameter.Method.POST ) {
+		if ( isPRG() && !session_f && param.getMethod() == RequestParameter.Method.POST ) {
 			data.redirect( out_ret, fw, param ).Action( this, res );
 		}
 		else {
