@@ -139,12 +139,12 @@ public class Form extends Tag implements PageHooker {
 
 	public void commitDaemon() {
 		StringBuilder	buf = new StringBuilder( "function(ev){" );
-		buf = buf.append( "if(paraselene_form_kill)return;" );
-		buf = buf.append( "if(!paraselene_agency_form(paraselene_get_id('" );
+		buf = buf.append( "if(paraselene.form_kill)return;" );
+		buf = buf.append( "if(!paraselene.agency_form(paraselene.get_id('" );
 		buf = buf.append( makeID() );
 		buf = buf.append( "'),'" );
 		buf = buf.append( getAssignedPage().getUniqueKey() );
-		buf = buf.append( "'))paraselene_kill_event(ev);}" );
+		buf = buf.append( "'))paraselene.kill_event(ev);}" );
 		setAnonymousEventHandler( "submit", buf.toString() );
 	}
 
